@@ -39,7 +39,7 @@ _help_postgres_options = "Postgres executable extra parameters. Passed via the -
 def pytest_addoption(parser: Parser) -> None:
     """Configure options for pytest-postgresql."""
     parser.addini(
-        name="postgresql_exec", help=_help_executable, default="/usr/lib/postgresql/9.6/bin/pg_ctl"
+        name="postgresql_exec", help=_help_executable, default="/usr/lib/postgresql/13/bin/pg_ctl"
     )
 
     parser.addini(name="postgresql_host", help=_help_host, default="127.0.0.1")
